#!/bin/sh
echo 'name: data-lens-template
version: 2.1.5
id: data-lens-template-2.1.5-045413013b899bef8c019a7db754bedf

license: BSD3
copyright:
maintainer: Edward Kmett <ekmett@gmail.com>
stability:
homepage: http://github.com/ekmett/data-lens-template/
package-url:
synopsis: Utilities for Data.Lens
description: Automatically derive @Lens@es for your data type for use with @Data.Lens@. Note: the code is derived from data-accessor-template <http://hackage.haskell.org/package/data-accessor-template> by Luke Palmer and Henning Thielemann.
category: Data
author: Joel Burget <joelburget@gmail.com>
pkgpath: devel/hs-data-lens-template
exposed: True
exposed-modules: Data.Lens.Template
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/data-lens-template-2.1.5
library-dirs: /usr/local/lib/ghc/data-lens-template-2.1.5
hs-libraries: HSdata-lens-template-2.1.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         data-lens-2.10.2-e2e5e12add54c150ab5e7c90446f5024
         template-haskell-2.7.0.0-826c08e99d445bf7fa4a34d70f491207
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-data-lens-template-2.1.5/html/data-lens-template.haddock
haddock-html: /usr/local/share/doc/hs-data-lens-template-2.1.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
